# ModelJobOutputResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**model_job** | [**ModelJobOutputJoinedModelJobResponseDto**](ModelJobOutputJoinedModelJobResponseDto.md) |  | [optional] 
**dataset** | [**ModelJobOutputJoinedDatasetResponseDto**](ModelJobOutputJoinedDatasetResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **object** |  | 
**data** | **object** |  | 
**model_job_id** | **str** |  | 
**dataset_id** | **str** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

